@@ -21,17 +21,41 @@ sub errCodes {
 }
 
 sub waitfor {
-  my ($self, $prompt) = @_;
+  my ($self, $prompt, $params) = @_;
+
+  croak "当同时定义 prompt 和 params 时，'params' 必须是一个哈希引用" if $prompt && $prompt && ref($params) ne 'HASH';
 
   my $buff = "";
+
   $prompt //= $self->{prompt};
 
   my $exp = $self->{exp};
 
-  my @ret = $exp->expect(
-    15,
+  my $exp_rule;
+  if ($prompt && !$params) {
+    $exp_rule = [
+      qr/$prompt/mi => sub {
+        $buff .= $exp->before() . $exp->match();
+      }
+    ];
+  }
+  elsif ($prompt && $params) {
+    $exp_rule = [
+      qr/$prompt/mi => sub {
+        my $send     = $params->{send}     // '';
+        my $continue = $params->{continue} // 0;
+        my $cache    = $params->{cache}    // 1;
+
+        $self->send($send)                      if !!$send;
+        $buff .= $exp->before() . $exp->match() if !!$cache;
+        exp_continue                            if !!$continue;
+      }
+    ];
+  }
+
+  my $handles = [
     [
-      qr/^\s*---- More ----\s*$/mi => sub {
+      qr/^\s*---- More ----\s*$/i => sub {
         $self->send(" ");
         $buff .= $exp->before();
         exp_continue;
@@ -58,22 +82,21 @@ sub waitfor {
         exp_continue;
       }
     ],
-    [
-      qr/$prompt/mi => sub {
-        $buff .= $exp->before() . $exp->match();
-      }
-    ],
     [
       eof => sub {
-        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
       }
     ],
-  );
+  ];
+
+  splice(@{$handles}, -2, 0, $exp_rule);
+
+  my @ret = $exp->expect($self->{timeout}, @{$handles});
 
   croak($ret[3]) if defined $ret[1];
 
@@ -124,21 +147,21 @@ sub getConfig {
 sub ftpConfig {
   my ($self, $hostname, $server, $username, $password) = @_;
 
-  if (!$self->{exp}) {
-    my $login = $self->login();
-    croak $login->{reason} if $login->{success} == 0;
-  }
-
   $server   //= $ENV{PDK_FTP_SERVER};
   $username //= $ENV{PDK_FTP_USERNAME};
   $password //= $ENV{PDK_FTP_PASSWORD};
 
   croak "请正确提供 FTP 服务器地址、账户和密码!" unless $username and $password and $server;
 
+  if (!$self->{exp}) {
+    my $login = $self->login();
+    croak $login->{reason} if $login->{success} == 0;
+  }
+
   my $host    = $self->{host};
   my $command = "put vrpcfg.zip $self->{month}/$self->{date}/";
 
-  if ($hostname) {
+  if (!!$hostname) {
     $command .= $hostname . '_' . $host . '.zip';
   }
   else {
@@ -151,8 +174,9 @@ sub ftpConfig {
   my $ftp_cmd = "ftp $server vpn-instance default";
   $self->dump("生成 FTP 备份指令：$ftp_cmd");
 
-  $self->dump("正在连接 FTP 服务器");
   $self->send("$ftp_cmd\n");
+  $self->dump("正在连接 FTP 服务器");
+
   my @ret = $exp->expect(
     15,
     [
@@ -170,12 +194,12 @@ sub ftpConfig {
     ],
     [
       eof => sub {
-        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
       }
     ],
   );
@@ -197,12 +221,12 @@ sub ftpConfig {
     ],
     [
       eof => sub {
-        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
       }
     ],
   );
@@ -226,12 +250,12 @@ sub ftpConfig {
     ],
     [
       eof => sub {
-        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
       }
     ],
   );
